@@ -6,7 +6,7 @@ Toadfarm - One Mojolicious app to rule them all
 
 =head1 VERSION
 
-0.66
+0.67
 
 =head1 DESCRIPTION
 
@@ -159,7 +159,7 @@ use File::Spec;
 use File::Which;
 use constant DEBUG => $ENV{TOADFARM_DEBUG} ? 1 : 0;
 
-our $VERSION = '0.66';
+our $VERSION = '0.67';
 
 BEGIN {
   $ENV{TOADFARM_ACTION} //= (@ARGV and $ARGV[0] =~ /^(reload|start|stop)$/) ? $1 : 'load';
@@ -283,8 +283,8 @@ sub _mount_apps {
     }
 
     $path = File::Which::which($path) || class_to_path($path) unless -r $path;
-    $app ||= eval { $server->load_app($path) }  or push @error, $@;
-    $app ||= eval { $server->build_app($name) } or push @error, $@;
+    $app ||= eval { $server->build_app($name) } or push @error, $@ if $name =~ /^[\w:]+$/;
+    $app ||= eval { $server->load_app($path) } or push @error, $@;
 
     if (!$app) {
       die join "\n", @error;
