@@ -23,7 +23,10 @@ Go to "https://github.com/YOUR-USERNAME/YOUR-REPO/settings/hooks" to set it up.
 =item *
 
 The WebHook URL needs to be "http://yourserver.com/some/secret/path" and
-should not trigger any of the mounted apps.
+should not trigger any of the mounted apps, e.g. with
+L<virtual hosts|Toadfarm::Manual::VirtualHost>, the hostname part of the
+WebHook URL need to be unique from the mounted apps. One way to do this is
+simply to use an IP address instead of a hostname.
 
 =back
 
@@ -82,6 +85,10 @@ each time you push to "master":
   $ git push origin release
   # This plugin will cause hypnotoad to hot deploy
 
+Note: The local branch will have the name "toadfarm_reload_branch". The reason
+for this is to avoid killing commits done manually in the local branch. This
+is of course a very bad workflow, and should be avoided.
+
 =item * path
 
 This is the path on disk to the local git repo.
